/*
 * Copyright 1999,2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package org.apache.catalina.tribes.membership;

import org.apache.catalina.tribes.util.Arrays;


/**
 * Manifest constants for the <code>org.apache.catalina.tribes.membership</code>
 * package.
 *
 * @author Peter Rossbach
 * @version $Revision: 303950 $ $Date: 2005-06-09 15:38:30 -0500 (Thu, 09 Jun 2005) $
 * @author Filip Hanik
 */

public class Constants {

    public static final String Package = "org.apache.catalina.tribes.membership";
    public static void main(String[] args) throws Exception {
        System.out.println(Arrays.toString("TRIBES-B".getBytes()));
        System.out.println(Arrays.toString("TRIBES-E".getBytes()));
    }
}
